/* Copyright Howard Cheng (ACM ICPC ECNA 1999) */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>

#define MAX_N 100

typedef struct {
  int seed, left, right;
} Node;

typedef struct {
  int present, node;
} Info;

Node tree[2*MAX_N-1];
int n, m;

void build_tree(int rounds)
{
  Info info[2][MAX_N+1];
  int next_node = 0, i, k, s;
  int turn = 0;

  for (i = 1; i <= n; i++) {
    tree[next_node].left = tree[next_node].right = -1;
    tree[next_node].seed = i;
    info[turn][i].present = 1;
    info[turn][i].node = next_node++;
  }
  for (s = 1, i = 0; i < rounds; s *= 2, i++)
    ;
  s++;

  for (k = rounds; k >= 1; k--) {
    for (i = 1; i <= n; i++) {
      info[1-turn][i].present = 0;
    }
    for (i = 1; i <= s/2 && i <= n; i++) {
      if (info[turn][i].present && s-i <= n && info[turn][s-i].present) {
	tree[next_node].left = info[turn][i].node;
	tree[next_node].right = info[turn][s-i].node;
	tree[next_node].seed = i;
	info[1-turn][i].present = 1;
	info[1-turn][i].node = next_node++;
      } else {
	info[1-turn][i] = info[turn][i];
      }
    }
    turn = 1 - turn;
    s = (s-1)/2 + 1;
  }

  assert(info[turn][1].present);
  assert(next_node == 2*n-1);
}

int search_tree(int root, char *p, int round)
{
  char leftp[MAX_N+1], rightp[MAX_N+1];
  int i, l, r;

  memset(p, 0, n+1);
  if (tree[root].left == -1 && tree[root].right == -1) {
    p[tree[root].seed] = 1;
    return -1;
  }

  l = search_tree(tree[root].left, leftp, round+1);
  r = search_tree(tree[root].right, rightp, round+1);

  if (l > 0 || r > 0) {
    return (l > r) ? l : r;
  }

  for (i = 1; i <= n; i++) {
    p[i] = leftp[i] | rightp[i];
  }

  for (i = 1; i <= n && i <= m-1; i++) {
    if (leftp[i] && m-i <= n && rightp[m-i]) {
      return round;
    }
  }
  return -1;
}

void print_tree(int v, int round)
{
  int l, r;
  if (tree[v].left == -1) {
    return;
  }
  print_tree(tree[v].left, round+1);
  print_tree(tree[v].right, round+1);
  l = tree[v].left; l = tree[l].seed;
  r = tree[v].right; r = tree[r].seed;
  printf("round = %d, %d plays %d\n", round, l, r);

}

int main(void)
{
  char p[2*MAX_N];
  int rounds, i, ans, cases = 0, t;

  while ((t = scanf("%d %d", &n, &m)) && !(n == 0 && m == 0)) {
    assert(t == 2);
    assert(2 <= n && n <= MAX_N && 3 <= m && m <= 2*n-1);
    for (rounds = 1, i = 2; i < n; rounds++, i *= 2) 
      ;
    build_tree(rounds);
/*    print_tree(2*n-2, rounds); */
    ans = search_tree(2*n-2, p, 1);
    assert(ans > 0);
    printf("Case %d: Round %d\n", ++cases, rounds-ans+1);
  }
  assert(t == 2);
  return 0;
}
