/* Copyright John Bonomo (ACM ICPC ECNA 1999) */

#include <iostream>

const int MAXSIZE = 100;
const int MAXROUNDS = 7;

bool rounds[MAXROUNDS+1];

struct tnode {
  int seed;
  tnode *left, *right;
};

tnode *buildTree(int n, int rndtotal, int seed)
  //
  // Builds tournment tree
  //
{
  tnode *node = new tnode;
  if (rndtotal - seed > n) {
    node->seed = seed;
    node->left = node->right = 0;
  }
  else {
    node->left = buildTree(n,2*rndtotal-1,seed);
    node->right = buildTree(n,2*rndtotal-1,rndtotal-seed);
  }
  return node;
}

void printtree(tnode *t, int rnd)
  //
  // print routine used in debugging
  //
{
  if (t->left != 0) {
    printtree(t->left, rnd-1);
    printtree(t->right, rnd-1);
  }
  else {
    cout << "Round " << rnd << ": Seed " << t->seed << endl;
  }
}

tnode* processTree(tnode* t, int m, int round)
  //
  // determines at each level which seeds can occur, and
  // checks for a specific match strength
  //
  // t - the tree
  // m - the match strength to look for
  // round - the current round
  //
  // return - list of seeds which could reach this level
  //
{
  if (t->left == 0) {
    tnode *temp = new tnode;
    temp->seed = t->seed;
    temp->left = 0;
    return temp;
  }
  else {
    tnode* llist = processTree(t->left, m, round-1);  // get seed lists from
    tnode* rlist = processTree(t->right, m, round-1); //   children
    tnode* t1;
    for(t1 = llist; t1 != 0; t1=t1->left)             // check for specified
      for(tnode *t2 = rlist; t2 != 0; t2=t2->left)   //   match strength
	if (t1->seed + t2->seed == m)
	  rounds[round] = true;                       // Found it!

    for(t1 = llist; t1->left != 0; t1=t1->left)       // combine seed lists
      ;
    t1->left = rlist;
    return llist;
  }
}

void main()
{
  int n, m, cases=0;;
  tnode *tree;
  cin >> n >> m;
  while (n != 0) {
    cases++;
    int numr = 1, temp = 2;
    while (temp < n) {                           // determine number of rounds
      numr++;
      temp *= 2;
    }
    for(int i=1; i<=numr; i++)
      rounds[i] = false;
    tree = buildTree(n, 3, 1);
    processTree(tree, m, numr);
    cout << "Case " << cases;
    for(int i=1; i<=numr; i++)
      if (rounds[i]) {
	cout << ": Round " << i << endl;
	break;
      }
    cin >> n >> m;
  }
}
