/* Copyright John Bonomo (ACM ICPC ECNA 1999) */

import java.io.*;
import java.util.StringTokenizer;

public class C_j {

        static final int MAXSIZE = 100;
        static final int MAXROUNDS = 7;

        static boolean [] rounds = new boolean[MAXROUNDS+1];
        static DataInputStream in = new DataInputStream(System.in);

        public static tnode buildTree(int n, int rndtotal, int seed)
        //
        // Builds tournment tree
        //
        {
                tnode node = new tnode();
                if (rndtotal - seed > n) {
                        node.seed = seed;
                        node.left = node.right = null;
                }
                else {
                        node.left = buildTree(n,2*rndtotal-1,seed);
                        node.right = buildTree(n,2*rndtotal-1,rndtotal-seed);
                }
                return node;
	}

        static void printtree(tnode t, int rnd)
        //
        // print routine used in debugging
        //
        {
                if (t.left != null) {
                        printtree(t.left, rnd-1);
                        printtree(t.right, rnd-1);
                }
                else {
                        System.out.println("Round " + rnd + ": Seed " + t.seed);                }
        }

        static tnode processTree(tnode t, int m, int round)
        //
        // determines at each level which seeds can occur, and
        // checks for a specific match strength
        //
        // t - the tree
        // m - the match strength to look for
        // round - the current round
        //
        // return - list of seeds which could reach this level
        //
        {
                if (t.left == null) {
                        tnode temp = new tnode();
                        temp.seed = t.seed;
                        temp.left = null;
                        return temp;
                }
                else {
                        tnode llist = processTree(t.left, m, round-1);  // get seed lists from
                        tnode rlist = processTree(t.right, m, round-1); //   children
                        tnode t1;
                        for(t1 = llist; t1 != null; t1=t1.left)             // check for specified
                                for(tnode t2 = rlist; t2 != null; t2=t2.left)   //   match strength
                                if (t1.seed + t2.seed == m)
                                        rounds[round] = true;                       // Found it!

                    for(t1 = llist; t1.left != null; t1=t1.left)       // combine seed lists
                                ;
                        t1.left = rlist;
                        return llist;
                }
        }

        public static void main(String [] args)
        {
                int cases=0;;
                tnode tree;
                String line="";
                try {line = in.readLine();} catch(IOException e) {}
                StringTokenizer str = new StringTokenizer(line);
                int n = Integer.parseInt(str.nextToken());
                int m = Integer.parseInt(str.nextToken());
                while (n != 0) {
                        cases++;
                        int numr = 1, temp = 2;
                        while (temp < n) {                           // determine number of rounds
                                numr++;
                                temp *= 2;
                        }
                        for(int i=1; i<=numr; i++)
                                rounds[i] = false;
                        tree = buildTree(n, 3, 1);
                        processTree(tree, m, numr);
                        System.out.print("Case " + cases);
                        for(int i=1; i<=numr; i++)
                                if (rounds[i]) {
                                        System.out.println(": Round " + i);
                                        break;
                                }

                        try {line = in.readLine();} catch(IOException e) {}
                        str = new StringTokenizer(line);
                        n = Integer.parseInt(str.nextToken());
                        m = Integer.parseInt(str.nextToken());
                }
        }
}

class tnode {
  public int seed;
  public tnode left, right;
};

